@@ -1,15 +1,26 @@
 """Domain-specific language for computational magnetism."""
-import pytest
 import pkg_resources
+import pytest
+
 import micromagneticmodel.abstract
 import micromagneticmodel.consts
 import micromagneticmodel.examples
-from .energy import EnergyTerm, Exchange, Zeeman, UniaxialAnisotropy, \
-    CubicAnisotropy, Demag, Zeeman, DMI, MagnetoElastic, RKKY, Energy
-from .dynamics import DynamicsTerm, Precession, Damping, ZhangLi, \
-    Slonczewski, Dynamics
-from .evolver import Evolver
+
 from .driver import Driver
+from .dynamics import Damping, Dynamics, DynamicsTerm, Precession, Slonczewski, ZhangLi
+from .energy import (
+    DMI,
+    RKKY,
+    CubicAnisotropy,
+    Demag,
+    Energy,
+    EnergyTerm,
+    Exchange,
+    MagnetoElastic,
+    UniaxialAnisotropy,
+    Zeeman,
+)
+from .evolver import Evolver
 from .system import System
 
 __version__ = pkg_resources.get_distribution(__name__).version
@@ -27,5 +38,6 @@ def test():
     >>> # micromagneticmodel.test()
 
     """
-    return pytest.main(['-v', '--pyargs',
-                        'micromagneticmodel', '-l'])  # pragma: no cover
+    return pytest.main(
+        ["-v", "--pyargs", "micromagneticmodel", "-l"]
+    )  # pragma: no cover
