@@ -2,41 +2,44 @@ import abc
 
 
 class Container(metaclass=abc.ABCMeta):
+    """Container abstract class.
+
+    Container can be initialised with a list of either energy or
+    dynamics terms.
+
+    Parameters
+    ----------
+    terms : list, optional
+
+        A list of either energy or dynamics terms. Defaults to ``None``. If
+        ``terms`` is not passed, an empty container is initialised.
+
+    Examples
+    --------
+    1. Defining energy terms container.
+
+    >>> import micromagneticmodel as mm
+    ...
+    >>> terms = [mm.Exchange(A=1e-12), mm.Demag()]
+    >>> energy = mm.Energy(terms=terms)
+    >>> len(energy)  # the number of terms
+    2
+
+    2. Defining dynamics terms container, by adding terms individually.
+
+    >>> dynamics = mm.Dynamics()
+    >>> len(dynamics)
+    0
+    >>> dynamics += mm.Precession(gamma0=mm.consts.gamma0)
+    >>> len(dynamics)
+    1
+    >>> dynamics += mm.Damping()
+    >>> len(dynamics)
+    2
+
+    """
+
     def __init__(self, terms=None):
-        """Container can be initialised with a list of either energy or
-        dynamics terms.
-
-        Parameters
-        ----------
-        terms : list, optional
-
-            A list of either energy or dynamics terms. Defaults to ``None``. If
-            ``terms`` is not passed, an empty container is initialised.
-
-        Examples
-        --------
-        1. Defining energy terms container.
-
-        >>> import micromagneticmodel as mm
-        ...
-        >>> terms = [mm.Exchange(A=1e-12), mm.Demag()]
-        >>> energy = mm.Energy(terms=terms)
-        >>> len(energy)  # the number of terms
-        2
-
-        2. Defining dynamics terms container, by adding terms individually.
-
-        >>> dynamics = mm.Dynamics()
-        >>> len(dynamics)
-        0
-        >>> dynamics += mm.Precession(gamma0=mm.consts.gamma0)
-        >>> len(dynamics)
-        1
-        >>> dynamics += mm.Damping()
-        >>> len(dynamics)
-        2
-
-        """
         self._terms = list()
         if terms is not None:
             for term in terms:
@@ -46,9 +49,7 @@ class Container(metaclass=abc.ABCMeta):
     @property
     @abc.abstractmethod
     def _term_class(self):
-        """The class of terms which can be added to ``Container``.
-
-        """
+        """The class of terms which can be added to ``Container``."""
         pass  # pragma: no cover
 
     def __len__(self):
@@ -196,7 +197,7 @@ class Container(metaclass=abc.ABCMeta):
             if term.name == attr:
                 return term
         else:
-            msg = f'Object has no attribute {attr}.'
+            msg = f"Object has no attribute {attr}."
             raise AttributeError(msg)
 
     def __dir__(self):
@@ -328,16 +329,14 @@ class Container(metaclass=abc.ABCMeta):
 
         if isinstance(other, self._term_class):
             if other in result:
-                msg = (f'Cannot have two {other.__class__} '
-                       'terms in the container.')
+                msg = f"Cannot have two {other.__class__} terms in the container."
                 raise ValueError(msg)
             result._terms.append(other)
         elif isinstance(other, self.__class__):
             for term in other:
                 result += term
         else:
-            msg = (f'Unsupported operand type(s) for +: '
-                   f'{type(self)} and {type(other)}.')
+            msg = f"Unsupported operand type(s) for +: {type(self)} and {type(other)}."
             raise TypeError(msg)
 
         return result
@@ -399,7 +398,7 @@ class Container(metaclass=abc.ABCMeta):
 
         if isinstance(other, self._term_class):
             if other not in result:
-                msg = f'Term {other.__class__} not in {self.__class__}.'
+                msg = f"Term {other.__class__} not in {self.__class__}."
                 raise ValueError(msg)
             for term in result:
                 if term.name == other.name:
@@ -408,8 +407,7 @@ class Container(metaclass=abc.ABCMeta):
             for term in other:
                 result -= term
         else:
-            msg = (f'Unsupported operand type(s) for +: '
-                   f'{type(self)} and {type(other)}.')
+            msg = f"Unsupported operand type(s) for +: {type(self)} and {type(other)}."
             raise TypeError(msg)
 
         return result
@@ -437,12 +435,12 @@ class Container(metaclass=abc.ABCMeta):
 
         """
         if len(self) == 0:
-            return f'{self.__class__.__name__}()'
+            return f"{self.__class__.__name__}()"
         else:
-            return ' + '.join([repr(term) for term in self])
+            return " + ".join([repr(term) for term in self])
 
     def _repr_latex_(self):
-        """"LaTeX representation method, rendered inside Jupyter. This method
+        """ "LaTeX representation method, rendered inside Jupyter. This method
         has the priority over ``__repr__`` in Jupyter.
 
         Returns
@@ -465,9 +463,9 @@ class Container(metaclass=abc.ABCMeta):
         >>> # energy  # inside Jupyter
 
         """
-        reprlatex = ''
+        reprlatex = ""
         if not self._terms:
-            reprlatex += '0'
+            reprlatex += "0"
         else:
             for term in self:
                 termlatex = term._reprlatex
@@ -475,10 +473,10 @@ class Container(metaclass=abc.ABCMeta):
                     # Adding the first term. No leading +.
                     reprlatex += termlatex
                 else:
-                    if not termlatex.startswith('-'):
+                    if not termlatex.startswith("-"):
                         # Is it the first term added to the sum? No leading +.
-                        reprlatex += f'+ {termlatex}'
+                        reprlatex += f"+ {termlatex}"
                     else:
                         reprlatex += termlatex
 
-        return f'${reprlatex}$'
+        return f"${reprlatex}$"
