@@ -1,5 +1,7 @@
 import abc
+
 import ubermagutil as uu
+
 import micromagneticmodel as mm
 
 
@@ -7,7 +9,7 @@ import micromagneticmodel as mm
 class DynamicsTerm(mm.abstract.Term):
     """A parent class for all dynamics terms."""
 
-    _container_class = 'Dynamics'
+    _container_class = "Dynamics"
 
     @abc.abstractmethod
     def dmdt(self, m, Heff):
