@@ -1,12 +1,14 @@
-import ubermagutil as uu
 import discretisedfield as df
+import ubermagutil as uu
 import ubermagutil.typesystem as ts
+
 from .dynamicsterm import DynamicsTerm
 
 
 @uu.inherit_docs
-@ts.typesystem(gamma0=ts.Parameter(descriptor=ts.Scalar(unsigned=True),
-                                   otherwise=df.Field))
+@ts.typesystem(
+    gamma0=ts.Parameter(descriptor=ts.Scalar(unsigned=True), otherwise=df.Field)
+)
 class Precession(DynamicsTerm):
     r"""Precession dynamics term.
 
@@ -54,9 +56,11 @@ class Precession(DynamicsTerm):
     ValueError: ...
 
     """
-    _allowed_attributes = ['gamma0']
-    _reprlatex = (r'-\frac{\gamma_{0}}{1 + \alpha^{2}} \mathbf{m} '
-                  r'\times \mathbf{H}_\text{eff}')
+    _allowed_attributes = ["gamma0"]
+    _reprlatex = (
+        r"-\frac{\gamma_{0}}{1 + \alpha^{2}} \mathbf{m} "
+        r"\times \mathbf{H}_\text{eff}"
+    )
 
     def dmdt(self, m, Heff):
         raise NotImplementedError
