@@ -1,5 +1,7 @@
 import abc
+
 import ubermagutil as uu
+
 import micromagneticmodel as mm
 
 
@@ -7,7 +9,7 @@ import micromagneticmodel as mm
 class EnergyTerm(mm.abstract.Term):
     """A parent class for all energy terms."""
 
-    _container_class = 'Energy'
+    _container_class = "Energy"
 
     def energy(self, m):
         raise NotImplementedError  # can be implemented as (Heff*m).integrate
