@@ -2,7 +2,6 @@ import micromagneticmodel as mm
 
 
 class Evolver(mm.abstract.Abstract):
-    """An abstract class for deriving evolvers.
+    """An abstract class for deriving evolvers."""
 
-    """
     pass
