@@ -1,7 +1,9 @@
 import re
+
 import pytest
-import discretisedfield as df
+
 import micromagneticmodel as mm
+
 from .checks import check_term
 
 
@@ -9,9 +11,9 @@ class TestDemag:
     def test_init_valid_arg(self):
         term = mm.Demag()
         check_term(term)
-        assert term.name == 'demag'
-        assert re.search(r'^Demag\(.*\)$', repr(term))
+        assert term.name == "demag"
+        assert re.search(r"^Demag\(.*\)$", repr(term))
 
     def test_init_invalid_args(self):
         with pytest.raises(AttributeError):
-            term = mm.Exchange(wrong=1)
+            mm.Exchange(wrong=1)
